This project aims to feel similar to using an ORMs (Object-Relational Mappers)
for databases. By using an object oriented approach, the user can interact with the API
in a way that is similar to interacting with objects in Python.